@@ -14,10 +14,12 @@
 
 
 import itertools
+from typing import List, Iterable
 
 import numpy as np
 
 from deeppavlov.core.common.metrics_registry import register_metric
+from deeppavlov.models.go_bot.nlg.dto.json_nlg_response import JSONNLGResponse
 
 
 @register_metric('accuracy')
@@ -34,11 +36,13 @@ def accuracy(y_true: [list, np.ndarray], y_predicted: [list, np.ndarray]) -> flo
     """
     examples_len = len(y_true)
     # if y1 and y2 are both arrays, == can be erroneously interpreted as element-wise equality
+
     def _are_equal(y1, y2):
         answer = (y1 == y2)
         if isinstance(answer, np.ndarray):
             answer = answer.all()
         return answer
+
     equalities = [_are_equal(y1, y2) for y1, y2 in zip(y_true, y_predicted)]
     correct = sum(equalities)
     return correct / examples_len if examples_len else 0
@@ -50,7 +54,7 @@ def multitask_accuracy(*args) -> float:
     Accuracy for multiple simultaneous tasks.
 
     Args:
-        *args: a list of `2n` inputs. The first `n` inputs are the correct answers for `n` tasks
+        *args: a list of `2n` inputs. The first `n` inputs are the correct answers for `n` tasks,
             and the last `n` are the predicted ones.
 
     Returns:
@@ -70,7 +74,7 @@ def multitask_sequence_accuracy(*args) -> float:
     are labeled correctly for all the individual taggers.
 
     Args:
-        *args: a list of `2n` inputs. The first `n` inputs are the correct answers for `n` tasks
+        *args: a list of `2n` inputs. The first `n` inputs are the correct answers for `n` tasks,
             and the last `n` are the predicted ones. For each task an
 
     Returns:
@@ -141,8 +145,11 @@ def per_token_accuracy(y_true, y_predicted):
     return correct / examples_len if examples_len else 0
 
 
+# region go-bot metrics
+
 @register_metric('per_item_dialog_accuracy')
-def per_item_dialog_accuracy(y_true, y_predicted):
+def per_item_dialog_accuracy(y_true, y_predicted: List[List[str]]):
+    # todo metric classes???
     y_true = [y['text'] for dialog in y_true for y in dialog]
     y_predicted = itertools.chain(*y_predicted)
     examples_len = len(y_true)
@@ -150,6 +157,23 @@ def per_item_dialog_accuracy(y_true, y_predicted):
     return correct / examples_len if examples_len else 0
 
 
+@register_metric("per_item_action_accuracy")
+def per_item_action_accuracy(dialogs_true, dialog_jsons_predicted: List[List[JSONNLGResponse]]):
+    # todo metric classes???
+    # todo oop instead of serialization/deserialization
+    utterances_actions_true = [utterance['act']
+                               for dialog in dialogs_true
+                               for utterance in dialog]
+
+    utterances_actions_predicted: Iterable[JSONNLGResponse] = itertools.chain(*dialog_jsons_predicted)
+    examples_len = len(utterances_actions_true)
+    correct = sum([y1.strip().lower() == '+'.join(y2.actions_tuple).lower()
+                   for y1, y2 in zip(utterances_actions_true, utterances_actions_predicted)])  # todo ugly
+    return correct / examples_len if examples_len else 0
+
+# endregion go-bot metrics
+
+
 @register_metric('acc')
 def round_accuracy(y_true, y_predicted):
     """
