@@ -247,7 +247,7 @@ class BertSequenceNetwork(LRScheduledTFModel):
             pretrained_bert = str(expand_path(pretrained_bert))
 
             if tf.train.checkpoint_exists(pretrained_bert) \
-                    and not tf.train.checkpoint_exists(str(self.load_path.resolve())):
+                    and not (self.load_path and tf.train.checkpoint_exists(str(self.load_path.resolve()))):
                 log.info('[initializing model with Bert from {}]'.format(pretrained_bert))
                 # Exclude optimizer and classification variables from saved variables
                 var_list = self._get_saveable_variables(
